powered by
Given the confidence level, it computes the confidence regions the effects for each arrow of the field3logit object.
field3logit
add_confregions_field3logit(x, conf = 0.95, npoints = 100)
Object of class field3logit with updated confidence regions.
an object of class field3logit.
confidence level of the region.
number of points of the border.
data(cross_1year) mod0 <- nnet::multinom(employment_sit ~ gender + finalgrade, data = cross_1year) field0 <- field3logit(mod0, 'genderFemale') plot3logit:::add_confregions_field3logit(field0)
Run the code above in your browser using DataLab