- mapping
list of aesthetic mappings to be used for plot. Mandatory
aesthetics should not be specified if field3loglit or multifield3logit
object is passed to data. See secion Aesthetic mappings of
gg3logit() for details.
- data
a field3logit object, a multifield3logit object, or
a data.frame structured like a fortified field3logit or a
multifield3logit object.
- geom
The geometric object to use display the data
- position
Position adjustment, either as a string, or the result of
a call to a position adjustment function.
- show.legend
logical. Should this layer be included in the legends?
NA, the default, includes if any aesthetics are mapped.
FALSE never includes, and TRUE always includes.
It can also be a named logical vector to finely select the aesthetics to
display.
- inherit.aes
If FALSE, overrides the default aesthetics,
rather than combining with them. This is most useful for helper functions
that define both data and aesthetics and shouldn't inherit behaviour from
the default plot specification, e.g. borders().
- arrow.
specification for arrow heads, as created by
function arrow of package grid.
- ...
additional arguments passed through to ggtern.